@@ -2,7 +2,7 @@
 
 '''
 Advanced Interface Switcher
-2010-2011(c) Kirill Plyashkevich <ru.spirit@gmail.com>
+2010-2012(c) Kirill Plyashkevich <ru.spirit@gmail.com>
 System menu plugin class
 '''
 
@@ -28,7 +28,7 @@ import advifswlib.util.locale as locale
 class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
 
   app_name = 'Advanced Interface Switcher'
-  version = '0.3.9'
+  version = '0.3.11'
   dev_author = 'Kirill Plyashkevich'
   dev_email = 'ru.spirit@gmail.com'
   dev_years = '2010-2012'
@@ -65,15 +65,23 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
                               gtk.EXPAND | gtk.FILL, 
                               gtk.SHRINK)
         loaded_ifaces += 1
-        loaded_list = '%s\n%s' % (loaded_list, 
-                                  self.__interfaces[iface[0]].get_name())
+        loaded_list = '%s\n%s (%s)' % (loaded_list, 
+                                  self.__interfaces[iface[0]].get_name(),
+                                  self.__interfaces[iface[0]].__class__)
       except Exception, e:
         loaded_list = '%s\n%s\nError: %s\n' % (loaded_list, iface[1], e)
         pass
+    print '\n%s\n%s' % (self.app_name, self.version)
     print '\nLoaded (%s/%s)%s\n' % (loaded_ifaces, len(ifaces), loaded_list)
     self.show_all()
 #    self.__show_settings_dialog()
 
+  def destroy(self):
+    for iface in self.__interfaces:
+      iface.destroy()
+    StatusMenuItem.destroy(self)
+    print '\n%s: destroyed' % (self.__class__.__name__)
+
   def __show_settings_dialog(self, button=None):
     self.__config.load()
     settings_dialog = gtk.Dialog(self.app_name, None,#self.window, 
