@@ -125,7 +125,7 @@ class GSMInterface(AbstractInterface):
   def turn_off(self):
     gobject.idle_add(self.run_commands, False)
 
-  def turn_mode(self, mode):
+  def turn_mode(self, mode, startup):
     gobject.idle_add(self.run_mode_commands, mode)
 
   def run_commands(self, flag):
