@@ -156,11 +156,7 @@ class WLANInterface(AbstractInterface):
   def turn_off(self):
     self.__cancel_autooff()
     if self.state['value'] != InterfaceState.off:
-      if self.state['value'] == InterfaceState.connected:
-        try:
-          self.get_interface('ICD').disconnect_req(dbus.UInt32(0x8000))
-        except:
-          self.reinit_interface('ICD')
+      self.disconnect()
       #run_async(self.run_commands, (self.wifi_turn_off_cmd,))
       gobject.idle_add(self.run_commands, self.wifi_turn_off_cmd)
     return False
@@ -201,6 +197,7 @@ class WLANInterface(AbstractInterface):
         self.state['mode'] = mode
         self.update()
       else:
+        self.disconnect()
         # down > unload > load%mode% > up
         gobject.idle_add(self.run_commands, [self.wifi_cmd['down'], self.wifi_cmd['load%s' % mode], self.wifi_cmd['up']])
     self.switched()
@@ -224,3 +221,10 @@ class WLANInterface(AbstractInterface):
       else:
         config = self.wifi_drivers.index(driver)
     return config
+
+  def disconnect(self):
+    if self.state['value'] == InterfaceState.connected:
+      try:
+        self.get_interface('ICD').disconnect_req(dbus.UInt32(0x8000))
+      except:
+        self.reinit_interface('ICD')
